gluestick [![Build Status](https://travis-ci.org/hotgluexyz/gluestick.svg?branch=master)](https://travis-ci.org/hotgluexyz/gluestick)
=============

A small Python module containing quick utility functions for standard ETL processes.

## Installation ##

```
pip install gluestick
```

## Links ##

* [Source]
* [Wiki]
* [Issues]
* [Slack]

## License ##
[MIT]

## Dependencies ##
* NumPy
* Pandas

## Contributing ##
This project is maintained by the [hotglue] team. We welcome contributions from the 
community via issues and pull requests.

If you wish to chat with our team, feel free to join our [Slack]!


[Source]: https://github.com/hotgluexyz/gluestick
[Wiki]: https://github.com/hotgluexyz/gluestick/wiki
[Issues]: https://github.com/hotgluexyz/gluestick/issues
[MIT]: https://tldrlegal.com/license/mit-license
[hotglue]: https://hotglue.xyz
[Slack]: https://bit.ly/2KBGGq1
